%global _name   mesonbuild

%bcond_with check

Name:           meson
Version:        0.52.1
Release:        %mkrel 1
Summary:        High productivity build system
Group:          System/Packaging
License:        ASL 2.0
URL:            http://mesonbuild.com/
Source0:        https://github.com/mesonbuild/meson/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/mesonbuild/meson/releases/download/%{version}/%{name}-%{version}.tar.gz.asc

Patch0:         meson-0.51.0-mageiaify-macros.patch

BuildArch:      noarch

BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)

%if %{with check}
BuildRequires:  locales
BuildRequires:  ninja

# Various languages
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gcc-gfortran
BuildRequires:  gcc-objc
BuildRequires:  gcc-objc++
BuildRequires:  java-devel
BuildRequires:  libasan-devel
BuildRequires:  llvm-devel
BuildRequires:  mono-core
BuildRequires:  pkgconfig(mono)
BuildRequires:  rust

# Various libs support
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gettext
BuildRequires:  git
BuildRequires:  gtk-doc
BuildRequires:  itstool
BuildRequires:  locales-en
BuildRequires:  vala
BuildRequires:  vala-tools
BuildRequires:  boost-devel
BuildRequires:  gnustep-base-devel
BuildRequires:  cups-devel
BuildRequires:  libwmf-devel
BuildRequires:  pcap-devel
BuildRequires:  qtbase5-devel
BuildRequires:  qttools5
BuildRequires:  wxgtk3.0-devel
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(glib-sharp-2.0)
BuildRequires:  pkgconfig(gmock)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(ompi)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vulkan)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  python3-gobject3
BuildRequires:  pythonegg(3)(cython)
%endif

Requires:       ninja
Requires:       python3dist(setuptools)

%description
Meson is a build system designed to optimize programmer productivity.
It aims to do this by providing simple, out-of-the-box support for
modern software development tools and practices, such as unit tests,
coverage reports, Valgrind, CCache and the like.

%prep
%autosetup -p1

find -type f -name '*.py' -executable -exec sed -i -e '1s|.*|#!%{__python3}|' {} ';'

# Remove MPI tests for now because it is complicated to run.
rm -rf "test cases/frameworks/17 mpi"

%build
%py3_build

%install
%py3_install

# install meson rpm macro helper
install -D -m 0644 data/macros.%{name} %{buildroot}%{_rpmmacrodir}/macros.%{name}

%if %{with check}
%check
export MESON_PRINT_TEST_OUTPUT=1
export LC_ALL=UTF-8
%{__python3} ./run_tests.py
%endif

%files
%doc README.md
%license COPYING
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1.*
%{_rpmmacrodir}/macros.%{name}
%{python3_sitelib}/%{_name}/
%{python3_sitelib}/%{name}-%{version}-py%{python3_version}.egg-info/
%{_datadir}/polkit-1/actions/com.mesonbuild.install.policy


%changelog
* Fri Sep 11 2020 ghibo <ghibo> 0.52.1-1.mga7
+ Revision: 1624767
- Update to release 0.52.1

* Wed Apr 17 2019 daviddavid <daviddavid> 0.50.1-1.mga7
+ Revision: 1391962
- new version: 0.50.1

* Mon Apr 08 2019 akien <akien> 0.50.0-3.mga7
+ Revision: 1386884
- Update Patch1 with the one that was merged upstream (same end result)
- Update Patch1 with the one that was merged upstream (same end result)

* Tue Mar 26 2019 akien <akien> 0.50.0-2.mga7
+ Revision: 1380380
- Add Fedora patch to set -Db_ndebug=true (rhbz#1692426)

* Sat Mar 16 2019 daviddavid <daviddavid> 0.50.0-1.mga7
+ Revision: 1377972
- new version: 0.50.0

* Tue Feb 05 2019 kekepower <kekepower> 0.49.2-1.mga7
+ Revision: 1363243
- Update to version 0.49.2

* Sun Jan 27 2019 wally <wally> 0.49.1-1.mga7
+ Revision: 1361290
- new version 0.49.1

* Sat Jan 05 2019 wally <wally> 0.49.0-2.mga7
+ Revision: 1349267
- rebuild for python3.7

* Mon Dec 10 2018 kekepower <kekepower> 0.49.0-1.mga7
+ Revision: 1339852
- Update to version 0.49.0
- Use python3dist()

* Fri Nov 09 2018 kekepower <kekepower> 0.48.2-1.mga7
+ Revision: 1329143
- Update to version 0.48.2

* Wed Oct 17 2018 kekepower <kekepower> 0.48.1-1.mga7
+ Revision: 1321743
- Update to version 0.48.1

* Thu Oct 11 2018 wally <wally> 0.48.0-1.mga7
+ Revision: 1319577
- new version 0.48.0

* Thu Sep 20 2018 umeabot <umeabot> 0.47.2-2.mga7
+ Revision: 1279508
- Mageia 7 Mass Rebuild

* Thu Aug 30 2018 daviddavid <daviddavid> 0.47.2-1.mga7
+ Revision: 1255701
- new version: 0.47.2
+ wally <wally>
- don't own dirs owned by polkit

* Mon Jul 23 2018 guillomovitch <guillomovitch> 0.47.1-1.mga7
+ Revision: 1245016
- new version 0.47.1

* Fri May 18 2018 kekepower <kekepower> 0.46.1-1.mga7
+ Revision: 1230390
- Change Release

* Fri May 18 2018 kekepower <kekepower> 0.46.1-0.1.mga7
+ Revision: 1230389
- Update to version 0.46.1

* Wed May 02 2018 kekepower <kekepower> 0.46.0-0.1.mga7
+ Revision: 1224594
- Update to version 0.46.0

* Thu Mar 22 2018 kekepower <kekepower> 0.45.1-0.1.mga7
+ Revision: 1211274
- Update to version 0.45.1

* Wed Mar 07 2018 kekepower <kekepower> 0.45.0-0.1.mga7
+ Revision: 1207129
- Update to version 0.45.0

* Wed Feb 21 2018 tv <tv> 0.44.1-0.1.mga7
+ Revision: 1203910
- new release (fix UTF-8 issues when building)

* Sun Dec 17 2017 wally <wally> 0.44.0-2.mga7
+ Revision: 1183048
- move UTF-8 locale fixes in rpm macros to ninja

* Sun Dec 17 2017 wally <wally> 0.44.0-1.mga7
+ Revision: 1183042
- build without tests
- new version 0.44.0
- rediff P0

* Thu Sep 21 2017 tv <tv> 0.42.1-1.mga7
+ Revision: 1156813
- new release

* Tue Aug 22 2017 ovitters <ovitters> 0.42.0-6.mga7
+ Revision: 1143299
- fix bug in locale forcing patch

* Tue Aug 22 2017 ovitters <ovitters> 0.42.0-5.mga7
+ Revision: 1143290
- improve locale forcing change

* Tue Aug 22 2017 ovitters <ovitters> 0.42.0-4.mga7
+ Revision: 1143285
- disable all buggy tests
- disable buggy test
- force UTF-8 LC_ALL for meson and ninja commands

* Mon Aug 21 2017 ovitters <ovitters> 0.42.0-3.mga7
+ Revision: 1142677
- require locales package

* Mon Aug 21 2017 ovitters <ovitters> 0.42.0-2.mga7
+ Revision: 1142645
- recommend locales package (easier for utf-8)

* Sat Aug 19 2017 daviddavid <daviddavid> 0.42.0-1.mga7
+ Revision: 1141655
- new version: 0.42.0

* Thu Aug 03 2017 tv <tv> 0.41.2-2.mga7
+ Revision: 1134480
- rebuild for new python

* Thu Jul 20 2017 daviddavid <daviddavid> 0.41.2-1.mga7
+ Revision: 1125513
- new version: 0.41.2

* Tue Jul 18 2017 tv <tv> 0.41.1-1.mga7
+ Revision: 1124743
- new release

* Sat Jun 03 2017 akien <akien> 0.38.0-3.mga6
+ Revision: 1106100
- Rebuild for wxgtk 3.0.3.1

* Thu Feb 02 2017 daviddavid <daviddavid> 0.38.0-2.mga6
+ Revision: 1084599
- mageiaify the meson macros

* Wed Feb 01 2017 daviddavid <daviddavid> 0.38.0-1.mga6
+ Revision: 1084507
- new version: 0.38.0

* Tue Dec 20 2016 daviddavid <daviddavid> 0.37.1-1.mga6
+ Revision: 1076236
- new version: 0.37.1

* Mon Dec 19 2016 daviddavid <daviddavid> 0.37.0-1.mga6
+ Revision: 1076164
- new version: 0.37.0

* Sun Dec 04 2016 daviddavid <daviddavid> 0.36.0-2.mga6
+ Revision: 1071916
- print test output during build

* Thu Nov 17 2016 daviddavid <daviddavid> 0.36.0-1.mga6
+ Revision: 1068018
- new version: 0.36.0
- add BRs itstool and vala-tools

* Tue Oct 18 2016 daviddavid <daviddavid> 0.35.1-1.mga6
+ Revision: 1061569
- new version: 0.35.1
- remove merged upstream patch

* Thu Oct 06 2016 daviddavid <daviddavid> 0.35.0-2.mga6
+ Revision: 1059159
- add upstream patch to fix missing dependency in gnome.mkenums test

* Tue Oct 04 2016 daviddavid <daviddavid> 0.35.0-1.mga6
+ Revision: 1058585
- new version: 0.35.0

* Sun Sep 25 2016 daviddavid <daviddavid> 0.34.0-1.mga6
+ Revision: 1056136
- imported package meson (based on Fedora)

